@@ -1,7 +1,7 @@
 import math
-import os
 from dataclasses import dataclass
 from dataclasses import field
+from pathlib import Path
 from textwrap import dedent
 from typing import Optional
 from typing import Tuple
@@ -23,14 +23,14 @@ import videoxt.validators as V
 
 @dataclass
 class BaseVideoExtractor:
-    video_path: str
+    video_path: Path
     start_time: Union[float, int, str] = 0.0
     stop_time: Optional[Union[float, int, str]] = None
     fps: Optional[float] = None
     dimensions: Optional[Tuple[int, int]] = None
     resize: float = 1.0
     rotate: int = 0
-    output_dir: Optional[str] = None
+    output_dir: Optional[Path] = None
     output_filename: Optional[str] = None
     monochrome: bool = False
     quiet: bool = True
@@ -42,10 +42,10 @@ class BaseVideoExtractor:
     stop_frame: int = field(init=False)
     stop_second: float = field(init=False)
     target_dimensions: Tuple[int, int] = field(init=False)
-    video_abspath: str = field(init=False)
+    video_abspath: Path = field(init=False)
     video_basename: str = field(init=False)
     video_dimensions: Tuple[int, int] = field(init=False)
-    video_dirname: str = field(init=False)
+    video_dirname: Path = field(init=False)
     video_filename: str = field(init=False)
     video_length: str = field(init=False)
     video_length_seconds: float = field(init=False)
@@ -92,18 +92,14 @@ class BaseVideoExtractor:
                 self.output_filename = V.valid_filename(self.output_filename)
 
     def _initialize_video_attributes(self) -> None:
-        self.video_abspath = (
-            self.video_path
-            if os.path.isabs(self.video_path)
-            else os.path.abspath(self.video_path)
-        )
-        self.video_dirname = os.path.dirname(self.video_abspath)
-        self.video_basename = os.path.basename(self.video_abspath)
-        self.video_filename = os.path.splitext(self.video_basename)[0]
+        self.video_abspath = self.video_path.resolve()
+        self.video_dirname = self.video_abspath.parent
+        self.video_basename = self.video_abspath.name
+        self.video_filename = self.video_abspath.stem
 
     def _initialize_video_metadata(self) -> None:
         """Video metadata initialized: frame count, fps, video length, and video dimensions."""
-        video_capture = cv2.VideoCapture(self.video_abspath)
+        video_capture = cv2.VideoCapture(str(self.video_abspath))
         self.frame_count = int(video_capture.get(cv2.CAP_PROP_FRAME_COUNT))
 
         if self.fps is None:
@@ -178,14 +174,12 @@ class BaseVideoExtractor:
         if self.extraction_type == "images":
             if self.output_dir is None:
                 output_dir_name = f"{self.video_filename}_frames"
-                output_dir = os.path.join(self.video_dirname, output_dir_name)
+                output_dir = self.video_dirname / output_dir_name
 
-                if os.path.exists(output_dir):
+                if output_dir.exists():
                     index = 2
-                    while os.path.exists(output_dir):
-                        output_dir = os.path.join(
-                            self.video_dirname, f"{output_dir_name} ({index})"
-                        )
+                    while output_dir.exists():
+                        output_dir = self.video_dirname / f"{output_dir_name} ({index})"
                         index += 1
 
                 self.output_dir = output_dir
@@ -198,13 +192,14 @@ class BaseVideoExtractor:
         """Set the default output filename for extracted frames or gif.
 
         For the 'images' extraction type:
-        If the output filename is not specified, the default filename will be the name of the video file
-        with '_frame' appended to the end.
+        If the output filename is not specified, the default filename will be the name of
+        the video file with '_frame' appended to the end.
 
         For the 'gif' extraction type:
-        If the output filename is not specified, the default filename will be the name of the video file
-        with '.gif' appended to the end. If the output filename is specified, the '.gif' extension will be
-        appended to the end of the filename if it is not already present.
+        If the output filename is not specified, the default filename will be the name of
+        the video file with '.gif' appended to the end. If the output filename is
+        specified, the '.gif' extension will be appended to the end of the filename if it
+        is not already present.
         """
         if self.extraction_type == "images":
             if self.output_filename is None:
@@ -246,14 +241,18 @@ class BaseVideoExtractor:
     def __str__(self) -> str:
         start_time_display = f"{utils.seconds_to_timestamp(self.start_second)} | {self.start_second} seconds"
         stop_time_display = f"{utils.seconds_to_timestamp(self.stop_second)} | {self.stop_second} seconds"
+        start_frame_display = f"{self.start_frame}"
+        stop_frame_display = f"{self.stop_frame}"
         if self.emoji:
             start_time_display = f"{C.EMOJI_MAP['start']} {start_time_display}"
             stop_time_display = f"{C.EMOJI_MAP['stop']} {stop_time_display}"
+            start_frame_display = f"{C.EMOJI_MAP['start']} {start_frame_display}"
+            stop_frame_display = f"{C.EMOJI_MAP['stop']} {stop_frame_display}"
 
         return dedent(
             f"""
             {'VIDEO' if not self.emoji else C.EMOJI_MAP['video']}
-              input:        {self.video_path!r}
+              path:         {self.video_abspath}
               length:       {self.video_length} | {self.video_length_seconds} seconds
               fps:          {self.fps}
               frame count:  {self.frame_count}
@@ -262,8 +261,8 @@ class BaseVideoExtractor:
               type:         {self.extraction_type!r}
               start time:   {start_time_display}
               stop time:    {stop_time_display}
-              start frame:  {self.start_frame if not self.emoji else C.EMOJI_MAP['start'] + ' ' + str(self.start_frame)}
-              stop frame:   {self.stop_frame if not self.emoji else C.EMOJI_MAP['stop'] + ' ' + str(self.stop_frame)}
+              start frame:  {start_frame_display}
+              stop frame:   {stop_frame_display}
               output dir:   {self.output_dir}"""
         )
 
@@ -305,13 +304,13 @@ class VideoToImages(BaseVideoExtractor):
         return image
 
     def extract_images(self) -> None:
-        video_capture = cv2.VideoCapture(self.video_path)
+        video_capture = cv2.VideoCapture(str(self.video_abspath))
         frame_position = self.start_frame
         video_capture.set(cv2.CAP_PROP_POS_FRAMES, frame_position)
 
         # Only creates the directory if the default output directory `video_frames_*.jpg` was used.
-        if not os.path.exists(str(self.output_dir)):
-            os.mkdir(str(self.output_dir))
+        if not self.output_dir.exists():
+            self.output_dir.mkdir()
 
         if not self.quiet:
             print(str(self))
@@ -327,7 +326,7 @@ class VideoToImages(BaseVideoExtractor):
                 read_successful, image = video_capture.read()
                 if read_successful:
                     image_filename = f"{self.output_filename}_{frame_position + 1}.{self.image_format}"
-                    image_path = os.path.join(str(self.output_dir), image_filename)
+                    image_path = str(self.output_dir / image_filename)
                     image = self._apply_image_transformations(image)
                     cv2.imwrite(image_path, image)
 
@@ -335,8 +334,9 @@ class VideoToImages(BaseVideoExtractor):
                         video_capture.release()
                         break
 
-                    # cv2.VideoCapture.read() increments and sets the next frame position by 1 on next read.
-                    # Therefore, the frame position is incremented by the capture rate only if capture rate > 1.
+                    # cv2.VideoCapture.read() increments by 1 and sets the next frame
+                    # position on next read. Therefore, the frame position is incremented
+                    # by the capture rate only if the capture rate is greater than 1.
                     frame_position += self.capture_rate
                     if self.capture_rate != 1:
                         video_capture.set(cv2.CAP_PROP_POS_FRAMES, frame_position)
@@ -344,7 +344,10 @@ class VideoToImages(BaseVideoExtractor):
                     progress.update(
                         extract_task,
                         advance=1,
-                        description=f"[yellow]EXTRACTING FRAMES FROM {self.video_basename!r} [{images_written}/{self.images_expected}]",
+                        description=(
+                            f"[yellow]EXTRACTING FRAMES FROM {self.video_basename!r}"
+                            f"[{images_written}/{self.images_expected}]"
+                        ),
                     )
 
                     images_written += 1
@@ -354,7 +357,8 @@ class VideoToImages(BaseVideoExtractor):
                     break
 
         print(
-            f"[green]EXTRACTION COMPLETE [{images_written}] IMAGES SAVED: {self.output_dir}[/green]"
+            f"[green]EXTRACTION COMPLETE [{images_written}] "
+            f"IMAGES SAVED: {self.output_dir}[/green]"
         )
 
     def __str__(self) -> str:
@@ -380,9 +384,9 @@ class VideoToImages(BaseVideoExtractor):
               format:       {self.image_format!r}
               resize:       {resize_display}
               rotate:       {rotate_display}
-              monochrome:   {self.monochrome}
               capture rate: {self.capture_rate}
               expected:     {self.images_expected}
+              monochrome:   {self.monochrome}
               dimensions:   {self.target_dimensions}
               """
         )
@@ -416,17 +420,18 @@ class VideoToGIF(BaseVideoExtractor):
         return subclip
 
     def create_gif(self) -> None:
-        with VideoFileClip(self.video_path, audio=False) as clip:
+        with VideoFileClip(str(self.video_abspath), audio=False) as clip:
             subclip = clip.subclip(self.start_second, self.stop_second)
             subclip = self._apply_gif_transformations(subclip)
 
-            gif_path = os.path.join(str(self.output_dir), str(self.output_filename))
+            gif_path = str(self.output_dir / self.output_filename)
 
             if not self.quiet:
                 print(str(self))
 
             with Console().status(
-                f"[yellow]CREATING GIF {self.output_filename!r} FROM {self.video_basename!r}[/yellow]"
+                f"[yellow]CREATING GIF {self.output_filename!r} "
+                f"FROM {self.video_basename!r}[/yellow]"
             ):
                 subclip.write_gif(
                     gif_path,
@@ -463,8 +468,8 @@ class VideoToGIF(BaseVideoExtractor):
               filename:     {self.output_filename!r}
               resize:       {resize_display}
               rotate:       {rotate_display}
-              monochrome:   {self.monochrome}
               speed:        {speed_display}
+              monochrome:   {self.monochrome}
               bounce:       {self.bounce}
               dimensions:   {self.target_dimensions}
               """
